Class: Google::Apis::TpuV1::TPUService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::TpuV1::TPUService
- Defined in:
- lib/google/apis/tpu_v1/service.rb
Overview
Cloud TPU API
TPU API provides customers with access to Google TPU technology.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://tpu.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_node(parent, node_object = nil, node_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Operation
Creates a node.
-
#delete_project_location_node(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Operation
Deletes a node.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Location
Gets information about a location.
-
#get_project_location_accelerator_type(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::AcceleratorType
Gets AcceleratorType.
-
#get_project_location_node(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Node
Gets the details of a node.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_tensorflow_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::TensorFlowVersion
Gets TensorFlow Version.
-
#initialize ⇒ TPUService
constructor
A new instance of TPUService.
-
#list_project_location_accelerator_types(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::ListAcceleratorTypesResponse
Lists accelerator types supported by this API.
-
#list_project_location_nodes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::ListNodesResponse
Lists nodes.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_tensorflow_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::ListTensorFlowVersionsResponse
List TensorFlow versions supported by this API.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#reimage_node(name, reimage_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Operation
Reimages a node's OS.
-
#start_node(name, start_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Operation
Starts a node.
-
#stop_node(name, stop_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Operation
Stops a node, this operation is only available with single TPU nodes.
Constructor Details
#initialize ⇒ TPUService
Returns a new instance of TPUService.
47 48 49 50 51 52 |
# File 'lib/google/apis/tpu_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-tpu_v1', client_version: Google::Apis::TpuV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/tpu_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/tpu_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
465 466 467 468 469 470 471 472 473 |
# File 'lib/google/apis/tpu_v1/service.rb', line 465 def cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.response_representation = Google::Apis::TpuV1::Empty::Representation command.response_class = Google::Apis::TpuV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_node(parent, node_object = nil, node_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Operation
Creates a node.
230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/google/apis/tpu_v1/service.rb', line 230 def create_project_location_node(parent, node_object = nil, node_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/nodes', ) command.request_representation = Google::Apis::TpuV1::Node::Representation command.request_object = node_object command.response_representation = Google::Apis::TpuV1::Operation::Representation command.response_class = Google::Apis::TpuV1::Operation command.params['parent'] = parent unless parent.nil? command.query['nodeId'] = node_id unless node_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_node(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Operation
Deletes a node.
263 264 265 266 267 268 269 270 271 |
# File 'lib/google/apis/tpu_v1/service.rb', line 263 def delete_project_location_node(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::TpuV1::Operation::Representation command.response_class = Google::Apis::TpuV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
498 499 500 501 502 503 504 505 506 |
# File 'lib/google/apis/tpu_v1/service.rb', line 498 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::TpuV1::Empty::Representation command.response_class = Google::Apis::TpuV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/tpu_v1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::TpuV1::Location::Representation command.response_class = Google::Apis::TpuV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_accelerator_type(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::AcceleratorType
Gets AcceleratorType.
155 156 157 158 159 160 161 162 163 |
# File 'lib/google/apis/tpu_v1/service.rb', line 155 def get_project_location_accelerator_type(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::TpuV1::AcceleratorType::Representation command.response_class = Google::Apis::TpuV1::AcceleratorType command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_node(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Node
Gets the details of a node.
293 294 295 296 297 298 299 300 301 |
# File 'lib/google/apis/tpu_v1/service.rb', line 293 def get_project_location_node(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::TpuV1::Node::Representation command.response_class = Google::Apis::TpuV1::Node command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
529 530 531 532 533 534 535 536 537 |
# File 'lib/google/apis/tpu_v1/service.rb', line 529 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::TpuV1::Operation::Representation command.response_class = Google::Apis::TpuV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_tensorflow_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::TensorFlowVersion
Gets TensorFlow Version.
608 609 610 611 612 613 614 615 616 |
# File 'lib/google/apis/tpu_v1/service.rb', line 608 def get_project_location_tensorflow_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::TpuV1::TensorFlowVersion::Representation command.response_class = Google::Apis::TpuV1::TensorFlowVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_accelerator_types(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::ListAcceleratorTypesResponse
Lists accelerator types supported by this API.
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/google/apis/tpu_v1/service.rb', line 193 def list_project_location_accelerator_types(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/acceleratorTypes', ) command.response_representation = Google::Apis::TpuV1::ListAcceleratorTypesResponse::Representation command.response_class = Google::Apis::TpuV1::ListAcceleratorTypesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_nodes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::ListNodesResponse
Lists nodes.
327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/google/apis/tpu_v1/service.rb', line 327 def list_project_location_nodes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/nodes', ) command.response_representation = Google::Apis::TpuV1::ListNodesResponse::Representation command.response_class = Google::Apis::TpuV1::ListNodesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'lib/google/apis/tpu_v1/service.rb', line 574 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::TpuV1::ListOperationsResponse::Representation command.response_class = Google::Apis::TpuV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_tensorflow_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::ListTensorFlowVersionsResponse
List TensorFlow versions supported by this API.
646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/google/apis/tpu_v1/service.rb', line 646 def list_project_location_tensorflow_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/tensorflowVersions', ) command.response_representation = Google::Apis::TpuV1::ListTensorFlowVersionsResponse::Representation command.response_class = Google::Apis::TpuV1::ListTensorFlowVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
can be called in two ways: * List all public locations: Use the path GET /
v1/locations. * List project-visible locations: Use the path GET /v1/
projects/project_id/locations. This may include public locations as well as
private or other locations specifically visible to the project.
121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/google/apis/tpu_v1/service.rb', line 121 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::TpuV1::ListLocationsResponse::Representation command.response_class = Google::Apis::TpuV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#reimage_node(name, reimage_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Operation
Reimages a node's OS.
360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/google/apis/tpu_v1/service.rb', line 360 def reimage_node(name, reimage_node_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:reimage', ) command.request_representation = Google::Apis::TpuV1::ReimageNodeRequest::Representation command.request_object = reimage_node_request_object command.response_representation = Google::Apis::TpuV1::Operation::Representation command.response_class = Google::Apis::TpuV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_node(name, start_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Operation
Starts a node.
393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/google/apis/tpu_v1/service.rb', line 393 def start_node(name, start_node_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:start', ) command.request_representation = Google::Apis::TpuV1::StartNodeRequest::Representation command.request_object = start_node_request_object command.response_representation = Google::Apis::TpuV1::Operation::Representation command.response_class = Google::Apis::TpuV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#stop_node(name, stop_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1::Operation
Stops a node, this operation is only available with single TPU nodes.
426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/google/apis/tpu_v1/service.rb', line 426 def stop_node(name, stop_node_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:stop', ) command.request_representation = Google::Apis::TpuV1::StopNodeRequest::Representation command.request_object = stop_node_request_object command.response_representation = Google::Apis::TpuV1::Operation::Representation command.response_class = Google::Apis::TpuV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |