Class: Google::Apis::TpuV1::Node
- Inherits:
-
Object
- Object
- Google::Apis::TpuV1::Node
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tpu_v1/classes.rb,
lib/google/apis/tpu_v1/representations.rb,
lib/google/apis/tpu_v1/representations.rb
Overview
A TPU instance.
Instance Attribute Summary collapse
-
#accelerator_type ⇒ String
Required.
-
#api_version ⇒ String
Output only.
-
#cidr_block ⇒ String
The CIDR block that the TPU node will use when selecting an IP address.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
The user-supplied description of the TPU.
-
#health ⇒ String
The health status of the TPU node.
-
#health_description ⇒ String
Output only.
-
#ip_address ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Resource labels to represent user-provided metadata.
-
#name ⇒ String
Output only.
-
#network ⇒ String
The name of a network they wish to peer the TPU node to.
-
#network_endpoints ⇒ Array<Google::Apis::TpuV1::NetworkEndpoint>
Output only.
-
#port ⇒ String
Output only.
-
#scheduling_config ⇒ Google::Apis::TpuV1::SchedulingConfig
Sets the scheduling options for this node.
-
#service_account ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#symptoms ⇒ Array<Google::Apis::TpuV1::Symptom>
Output only.
-
#tensorflow_version ⇒ String
Required.
-
#use_service_networking ⇒ Boolean
(also: #use_service_networking?)
Whether the VPC peering for the node is set up through Service Networking API.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Node
constructor
A new instance of Node.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Node
Returns a new instance of Node.
410 411 412 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 410 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_type ⇒ String
Required. The type of hardware accelerators associated with this node.
Corresponds to the JSON property acceleratorType
297 298 299 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 297 def accelerator_type @accelerator_type end |
#api_version ⇒ String
Output only. The API version that created this Node.
Corresponds to the JSON property apiVersion
302 303 304 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 302 def api_version @api_version end |
#cidr_block ⇒ String
The CIDR block that the TPU node will use when selecting an IP address. This
CIDR block must be a /29 block; the Compute Engine networks API forbids a
smaller block, and using a larger block would be wasteful (a node can only
consume one IP address). Errors will occur if the CIDR block has already been
used for a currently existing TPU node, the CIDR block conflicts with any
subnetworks in the user's provided network, or the provided network is peered
with another network that is using that CIDR block.
Corresponds to the JSON property cidrBlock
313 314 315 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 313 def cidr_block @cidr_block end |
#create_time ⇒ String
Output only. The time when the node was created.
Corresponds to the JSON property createTime
318 319 320 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 318 def create_time @create_time end |
#description ⇒ String
The user-supplied description of the TPU. Maximum of 512 characters.
Corresponds to the JSON property description
323 324 325 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 323 def description @description end |
#health ⇒ String
The health status of the TPU node.
Corresponds to the JSON property health
328 329 330 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 328 def health @health end |
#health_description ⇒ String
Output only. If this field is populated, it contains a description of why the
TPU Node is unhealthy.
Corresponds to the JSON property healthDescription
334 335 336 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 334 def health_description @health_description end |
#ip_address ⇒ String
Output only. DEPRECATED! Use network_endpoints instead. The network address
for the TPU Node as visible to Compute Engine instances.
Corresponds to the JSON property ipAddress
340 341 342 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 340 def ip_address @ip_address end |
#labels ⇒ Hash<String,String>
Resource labels to represent user-provided metadata.
Corresponds to the JSON property labels
345 346 347 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 345 def labels @labels end |
#name ⇒ String
Output only. Immutable. The name of the TPU
Corresponds to the JSON property name
350 351 352 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 350 def name @name end |
#network ⇒ String
The name of a network they wish to peer the TPU node to. It must be a
preexisting Compute Engine network inside of the project on which this API has
been activated. If none is provided, "default" will be used.
Corresponds to the JSON property network
357 358 359 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 357 def network @network end |
#network_endpoints ⇒ Array<Google::Apis::TpuV1::NetworkEndpoint>
Output only. The network endpoints where TPU workers can be accessed and sent
work. It is recommended that Tensorflow clients of the node reach out to the
0th entry in this map first.
Corresponds to the JSON property networkEndpoints
364 365 366 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 364 def network_endpoints @network_endpoints end |
#port ⇒ String
Output only. DEPRECATED! Use network_endpoints instead. The network port for
the TPU Node as visible to Compute Engine instances.
Corresponds to the JSON property port
370 371 372 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 370 def port @port end |
#scheduling_config ⇒ Google::Apis::TpuV1::SchedulingConfig
Sets the scheduling options for this node.
Corresponds to the JSON property schedulingConfig
375 376 377 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 375 def scheduling_config @scheduling_config end |
#service_account ⇒ String
Output only. The service account used to run the tensor flow services within
the node. To share resources, including Google Cloud Storage data, with the
Tensorflow job running in the Node, this account must have permissions to that
data.
Corresponds to the JSON property serviceAccount
383 384 385 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 383 def service_account @service_account end |
#state ⇒ String
Output only. The current state for the TPU Node.
Corresponds to the JSON property state
388 389 390 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 388 def state @state end |
#symptoms ⇒ Array<Google::Apis::TpuV1::Symptom>
Output only. The Symptoms that have occurred to the TPU Node.
Corresponds to the JSON property symptoms
393 394 395 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 393 def symptoms @symptoms end |
#tensorflow_version ⇒ String
Required. The version of Tensorflow running in the Node.
Corresponds to the JSON property tensorflowVersion
398 399 400 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 398 def tensorflow_version @tensorflow_version end |
#use_service_networking ⇒ Boolean Also known as: use_service_networking?
Whether the VPC peering for the node is set up through Service Networking API.
The VPC Peering should be set up before provisioning the node. If this field
is set, cidr_block field should not be specified. If the network, that you
want to peer the TPU Node to, is Shared VPC networks, the node must be created
with this this field enabled.
Corresponds to the JSON property useServiceNetworking
407 408 409 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 407 def use_service_networking @use_service_networking end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/google/apis/tpu_v1/classes.rb', line 415 def update!(**args) @accelerator_type = args[:accelerator_type] if args.key?(:accelerator_type) @api_version = args[:api_version] if args.key?(:api_version) @cidr_block = args[:cidr_block] if args.key?(:cidr_block) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @health = args[:health] if args.key?(:health) @health_description = args[:health_description] if args.key?(:health_description) @ip_address = args[:ip_address] if args.key?(:ip_address) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @network_endpoints = args[:network_endpoints] if args.key?(:network_endpoints) @port = args[:port] if args.key?(:port) @scheduling_config = args[:scheduling_config] if args.key?(:scheduling_config) @service_account = args[:service_account] if args.key?(:service_account) @state = args[:state] if args.key?(:state) @symptoms = args[:symptoms] if args.key?(:symptoms) @tensorflow_version = args[:tensorflow_version] if args.key?(:tensorflow_version) @use_service_networking = args[:use_service_networking] if args.key?(:use_service_networking) end |